pub enum Error {
UnmappedIndex {
index: usize,
},
OverlappingIndices,
IndexAlreadyInUse {
index: usize,
},
NotTheNextAvailableInsertionIndex {
expected_index: usize,
actual_index: usize,
},
}Expand description
The error type.
Variants
UnmappedIndex
The given index is not mapped to any element.
OverlappingIndices
The given indices contain an overlapping pair of indices.
IndexAlreadyInUse
The given index is already mapped to an element.
NotTheNextAvailableInsertionIndex
The given index is not the next available insertion index.